/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.core.text;

/**
 * 文字列ユーティリティー。
 *
 * @author KASHIHARA Shinji
 */
public class Strings {

	/**
	 * 隠されたコンストラクター。
	 * 
	 * <UL>
	 * <LI>このクラスはユーティリティ・クラスです。
	 * <LI>インスタンス生成を抑制するために、コンストラクターは private で修飾されています。
	 * </UL>
	 */
	private Strings() {
	}

	/**
	 * 連続する余分なホワイトスペースを除去。
	 * 
	 * <UL>
	 * <LI>連続する空白(ホワイトスペース)を 1 つに集約します。
	 * <LI>HTLM 4.01 の「White space」と関連のある処理です。
	 * <LI>ただし、「&amp;nbsp;」 は処理しません。
	 * </UL>
	 * 
	 * @param s 文字列
	 * @return 処理後の文字列
	 */
	public static String removeRedundantWhitespace(String s) {
		if (s == null) {
			return s;
		}
		s = s.trim();
		s = s.replaceAll("\\s+", " "); //$NON-NLS-1$ //$NON-NLS-2$
		return s;
	}

	/**
	 * ホワイトスペースで分割。
	 * 
	 * <UL>
	 * <LI>「&amp;nbsp;」 は処理しません。
	 * </UL>
	 * 
	 * @param s 文字列
	 * @return 分割後の文字列配列
	 */
	public static String[] splitByWhitespace(String s) {
		if (s == null) {
			return new String[] {};
		}
		return s.trim().split("\\s+"); //$NON-NLS-1$
	}
}
